import argparse


def f() -> None:
    pass


commands = {'ini': f, 'test': f}


def main() -> None:
    args: argparse.Namespace = parse_arguments()
    print(args.command)


def parse_arguments() -> argparse.Namespace:
    parser = argparse.ArgumentParser(description='basic tools for devops. Usage.')
    parser.add_argument('command', nargs='?', help='command to execute', choices=commands.keys())
    parser.add_argument('--file', nargs='?', help='file to parse')
    return parser.parse_args()


if __name__ == "__main__":
    main()



import getpass
import logging
import sqlite3
from datetime import datetime
from typing import Tuple, Text


class History(object):
    __current: int = -1

    def __init__(self, db_path: str, context: Tuple[Text, Text]) -> None:
        self.__conn = sqlite3.connect(db_path)
        self.__initialise_tables()
        self.__initialise_current(context=context)

    def __initialise_current(self, context: Tuple[Text, Text]) -> None:
        c = self.__conn.cursor()
        c.execute('''UPDATE Executions SET current=? WHERE current=?''', (0, 1))
        c.execute(
            '''INSERT INTO Executions(input_file, environment, timestamp, user, current) VALUES (?, ?, ?, ?, ?)''',
            (context[0], context[1], datetime.now(), getpass.getuser(), 1))
        self.__conn.commit()
        logging.info('current execution added to history db.')

    def __initialise_tables(self) -> None:
        c = self.__conn.cursor()
        c.execute('''SELECT name FROM sqlite_master WHERE type='table' AND name=?''', ('Executions',))
        if c.fetchone() is None:
            c.execute(
                '''CREATE TABLE Executions (id INTEGER PRIMARY KEY,  input_file TEXT NOT NULL,
                    environment varchar(20), timestamp DATETIME, user TEXT, current INTEGER)''')
            c.execute('''CREATE TABLE Logs (id INTEGER PRIMARY KEY, executionId INTEGER NOT NULL,
             record TEXT NOT NULL)''')
        self.__conn.commit()
        logging.info('history db initialised.')

    def get_current(self) -> int:
        if self.__current == -1:
            self.__current = self.__get_current_from_db()
        return self.__current

    def __get_current_from_db(self) -> int:
        c = self.__conn.cursor()
        c.execute('''SELECT id FROM Executions WHERE current=?''', (1,))
        row = c.fetchone()
        if row is None:
            raise StateError(message='No current execution in history db')
        return row[0]

    def persist(self, event: str) -> None:
        c = self.__conn.cursor()
        c.execute('''INSERT INTO Logs(executionId, record) VALUES (?, ?)''', (self.get_current(), event))
        self.__conn.commit()


class StateError(BaseException):
    def __init__(self, message: str):
        self.message = message



import logging
from typing import Dict, Any

from cloudevents.http import CloudEvent

from .history import History
from ..common.config import Config


def config2attributes(config: Config) -> Any:
    return config.get_section('CloudEvents')


class Report(object):
    def __init__(self, attributes: dict, history: History):
        self.__attributes: Dict = attributes
        self.__history = history

    def add_event(self, record: dict) -> None:
        event = CloudEvent(attributes=self.__attributes, data=record)
        logging.info(str(event))
        self.__history.persist(event=str(event))



import sys
from distutils.core import run_setup
from typing import Any, Text, Dict

ACCEPTED: Dict[Text, Any] = {
    'name': lambda a: a.get_name(),
    'author': lambda a: a.get_author(),
    'version': lambda a: a.get_version(),
    'all': lambda a: a.__dict__
}


def main(argv: Any) -> None:
    if len(argv) < 2 or argv[1] not in ACCEPTED.keys():
        usage_exit()
    else:
        result = run_setup('./setup.py', stop_after='init')
        print(ACCEPTED[argv[1]](result))


def usage_exit() -> None:
    print('Usage: \n\tpython3 -m devops.utils.read_setup <entry = name|author>')
    print('\n\tprint the value for <entry> found in the setup.py')
    sys.exit(-1)


if __name__ == "__main__":
    main(argv=sys.argv)



import chevron

from ..common.config import Config

TEMPLATES = 'templates'


def simple_render(template: str, data: dict) -> str:
    return chevron.render(template=template, data=data)


class Templates(object):

    def __init__(self, config: Config) -> None:
        self.config: Config = config

    def render(self, template_name: str, data: dict) -> str:
        file_path = self.config.get_file_path(TEMPLATES, '{}.mustache'.format(template_name))
        template: str
        with open(file_path, mode='r') as f:
            template = f.read()
        return simple_render(template, data)



import configparser
import json
import os

from typing import Dict, Text


class Config(object):

    def __init__(self, path_file: str):
        self.path_file = path_file
        self.config = configparser.ConfigParser()
        self.config.read(path_file)

    def get_value(self, section: str, key: str) -> str:
        return self.config[section][key]

    def get_section(self, section: str) -> Dict[Text, Text]:
        result = {}
        for key in self.config.options(section):
            result[key] = self.config.get(section, key)
        return result

    def get_path(self, key: str) -> str:
        return os.path.abspath(os.path.join(os.path.dirname(self.path_file), self.config['Paths'][key]))

    def get_file_path(self, key: str, file_name: str) -> str:
        return os.path.join(self.get_path(key=key), file_name)

    def get_json_file(self, key: str, file_name: str) -> dict:
        with open(self.get_file_path(key=key, file_name=file_name)) as json_file:
            return json.load(json_file)



from setuptools import setup

setup(
    author="David Navarro Alvarez",
    author_email="me@davengeo.com",
    description="devops base library dist",
    url="https://github.com/davengeo/devops-tools",
    name="devops-tools-daven",
    version='0.0.2',
    packages=[
        'devops',
        'devops.reports',
        'devops.common',
        'devops.templates',
        'devops.utils'
    ],
    install_requires=['chevron', 'cloudevents', 'json-spec', 'invoke', 'datasette'],
    package_data={
        'config': ['config/templates/hello_world.mustache', 'config/example/example.json'],
        'ini': ['app.ini']
    },
    include_package_data=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: European Union Public Licence 1.2 (EUPL 1.2)',
        'Programming Language :: Python :: 3.8',
        'Topic :: System :: Systems Administration',
    ]
)



import configparser
import sys
from typing import Any

config = configparser.ConfigParser()


def main(argv: Any) -> None:
    if len(argv) < 4:
        usage_exit()
    try:
        config.read_file(open(argv[1]))
        print(config.get(section=argv[2], option=argv[3]))
    except Exception as e:
        print_exception(e)
        usage_exit()


def print_exception(e: Exception) -> None:
    print(e)


def usage_exit() -> None:
    print('Usage: \n\tpython3 -m devops.utils.read_ini <ini-file> <section> <entry>')
    print('\n\tjust print the value for <entry> found in the indicated <section> of the <ini-file>')
    sys.exit(-1)


if __name__ == "__main__":
    main(argv=sys.argv)
